tfCoxThis function makes predictions from a specified covariate matrix for a fit of the class "tfCox".
# S3 method for tfCox
predict(object, newX, which.lambda=1, …)an object of the class "tfCox"
a n x p covariate matrix
the index for the model of interest to be plotted. which.lambda corresponds to the model fit in lambda.seq and should be integer between 1 to length(fit$lambda.seq). In other words, the fit from fit$theta.list[[which.lambda]] will be plotted.
additional arguments to be passed. These are ignored in this function.
A n x p matrix containing the fitted theta values.
Prediction for the new data point is implemented by constant or linear interpolation. 0th order trend filtering will have constant interpolation, and 1th or higher order trend filtering will have linear interpolation.