Learn R Programming

tfCox (version 0.1.0)

summary.cv_tfCox: Summarize cv_tfCox object

Description

This function summarizes cv_tfCox object and identifies the tuning parameter chosen by cross-validation.

Usage

# S3 method for cv_tfCox
summary(object, …)

Arguments

object

an object of class "cv_tfCox"

additional arguments to be passed. These are ignored in this function.

See Also

cv_tfCox, plot.cv_tfCox

Examples

Run this code
# NOT RUN {
#generate data
set.seed(1234)
dat = sim_dat(n=100, zerof=0, scenario=1)

#cross-validation to choose the tuning parameter lambda with fixed alpha=1
cv = cv_tfCox(dat, ord=0, alpha=1, n.fold=2)
#summarize the cross-validation
summary(cv)
#plot the cross-validation curve
plot(cv)
# }

Run the code above in your browser using DataLab