Learn R Programming

tfCox (version 0.1.0)

tfCox-package: Fit the Additive Trend Filtering Cox Model

Description

This package is called tfCox or trend filtering for Cox model, which is proposed in Jiacheng Wu & Daniela Witten (2019) Flexible and Interpretable Models for Survival Data, Journal of Computational and Graphical Statistics, DOI: 10.1080/10618600.2019.1592758. It provides an approach to fit additive Cox model in which each component function is estimated to be piecewise polynomial with adaptively-chosen knots.

Function tfCox fits the trend filtering Cox model for a range of tuning parameters. Function cv_tfCox returns the optimal tuning parameter selected by K-fold cross validation.

Arguments

Details

Package: tfCox
Type: Package
Version: 0.1.0
Date: 2019-05-20
License: GPL (>= 2)

The package includes the following functions: tfCox, cv_tfCox, plot.tfCox, plot.cv_tfCox, predict.tfCox, summary.tfCox, summary.cv_tfCox, sim_dat, plot.sim_dat.

References

Jiacheng Wu & Daniela Witten (2019) Flexible and Interpretable Models for Survival Data, Journal of Computational and Graphical Statistics, DOI: 10.1080/10618600.2019.1592758